# Python wrapper for Elevenlabs API

This is a python wrapper for the Elevenlabs API ([LINK](https://beta.elevenlabs.io/))

Currently only supports calling the text-to-speech endpoint.
Needs a api_key and voice_id to work. Api Key is available in your Profile. Voice Id is available [here](https://api.elevenlabs.io/v1/voices).

---

This package and repository is no way affiliated with Elevenlabs. Please ssend all support requests related to this python package to this Issue Tracker: [Issues](https://github.com/philiplawall/pyElevenlabs/issues)
